@@ -4,6 +4,7 @@
 #' Stacked (= tidy) data.frame to matrix
 #'
 #' Passes from a stacked (= tidy) data.frame to a matrix.
+#' \code{tidy_to_matrix()} is an alias of this function.
 #'
 #' @param my_df data.frame you want to transform in matrix
 #'
@@ -72,7 +73,8 @@ stack_to_matrix = tidy_to_matrix = function(my_df, col_to_row, col_to_col,
 #' Matrix to stacked (= tidy) data.frame
 #'
 #' From a matrix with values to a stacked (= tidy) data.frame, exclude NA from
-#' given data.frame.
+#' given data.frame. If supplied object is not a matrix, try to coerce object
+#' to matrix first. \code{matrix_to_tidy()} is an alias of this function.
 #'
 #' @param my_mat matrix you want to transform in stacked (= tidy) data.frame
 #'
@@ -129,6 +131,17 @@ matrix_to_stack = matrix_to_tidy = function(my_mat, value_col = "value",
     tidy_df = data.frame(rows_index = rownames(my_mat)[summ_df$i],
                          cols_index = colnames(my_mat)[summ_df$j],
                          val = summ_df$x)
+
+  } else if (is(my_mat, "Matrix")) {
+    # If matrix is a dense matrix from Matrix package
+    tidy_df = as.data.frame(as.table(as.matrix(my_mat)))
+
+  } else {
+    # Try coercion if possible
+    warning("Object is not a matrix. Coercing it to matrix")
+    real_mat = as.matrix(my_mat)
+
+    tidy_df = as.data.frame(as.table(real_mat))
   }
 
   tidy_df = na.exclude(tidy_df)
